==> cejs-4.5.4.tgz: package/application/locale/resources/de-DE.js <==
/*	Localized messages of CeL.
	This file is auto created by auto-generate tool: build.nodejs(.js) @ 2022.
*/'use strict';typeof CeL==='function'&&CeL.application.locale.gettext.set_text({
	"untranslated message count": "1000+",
	"Load failed": "Laden fehlgeschlagen",
	"\u5730\u7406\u5ea7\u6a19\uff1a": "Koordinaten: ",
	"\u81ea\u8a02\u8f38\u51fa\u683c\u5f0f": "Ausgabeformat anpassen",
	"\u7d93\u5ea6\uff1a": "Breitengrad: ",
	"\u7def\u5ea6\uff1a": "L\u00e4ngengrad: ",
	"\u8f38\u51fa\u683c\u5f0f": "Ausgabeformat",
	"\u524d\u7db4": "Pr\u00e4fix",
	"\u6642\u5340\uff1a": "Zeitzone: ",
	"Loading...": "Laden...",
	"\u1019\u103c\u1014\u103a\u1019\u102c": "Myanmar",
	"Vi\u1ec7t Nam": "Vietnam",
	"\u9664\u53bb\u6b64\u6b04": "Spalte entfernen",
	"\u5206\u985e": "Gruppe",
	"%1/%2/%3": "%1/%2/%3",
	"\u5168\u4e0d\u9078": "ALLE entfernen",
	"\u589e\u52a0\u6b64\u6b04": "Spalte hinzuf\u00fcgen",
	"\u81fa\u7063\u5730\u9707": "Erdbeben in Taiwan",
	"\u5c0e\u89bd\u5217\uff1a": "Navigation:",
	"\u6240\u6709\u570b\u5bb6": "Alle L\u00e4nder",
	"France": "Frankreich",
	"Great Britain": "Gro\u00dfbritannien",
	"Spain": "Spanien",
	"\u541b\u4e3b\u865f": "K\u00fcnstlername",
	"\u51fa\u751f": "Geboren",
	"\u901d\u4e16": "Gestorben",
	"\u5728\u4f4d": "Regierungszeit",
	"\u52a0\u5195": "Kr\u00f6nung",
	"\u524d\u4efb": "Vorg\u00e4nger",
	"\u7e7c\u4efb": "Nachfolger",
	"\u7236\u89aa": "Vater",
	"\u6bcd\u89aa": "Mutter",
	"Initializing...": "Initialisiere\u2026",
	"Aries": "Widder",
	"Taurus": "Stier",
	"Gemini": "Zwilling",
	"Cancer": "Krebs",
	"Leo": "L\u00f6we",
	"Virgo": "Jungfrau",
	"Libra": "Waage",
	"Scorpio": "Skorpion",
	"Sagittarius": "Sch\u00fctze",
	"Capricorn": "Steinbock",
	"Aquarius": "Wassermann",
	"Pisces": "Fische",
	"\u6708\u76f8": "Mondphase",
	"\u661f\u671f": "Wochentag",
	"\u6714": "Neumond",
	"\u65e5\u51fa\u65e5\u843d": "Sonnenaufgang / Sonnenuntergang",
	"\u66d9\u66ae\u5149": "D\u00e4mmerung",
	"\u6708\u51fa\u6708\u843d": "Mondaufgang / Monduntergang",
	"calendar": "Kalender",
	"Gregorian calendar": "Gregorianischer Kalender",
	"Julian calendar": "Julianischer Kalender",
	"\u4f0a\u65af\u862d\u66c6": "Islamischer Kalender",
	"\u06af\u0627\u0647\u200c\u0634\u0645\u0627\u0631\u06cc \u0647\u062c\u0631\u06cc \u062e\u0648\u0631\u0634\u06cc\u062f\u06cc": "Moderner iranischer Kalender",
	"\u5e0c\u4f2f\u4f86\u66c6": "Hebr\u00e4ischer Kalender",
	"\u9577\u7d00\u66c6": "Lange Z\u00e4hlung",
	"\u50a3\u66c6": "Dai-Kalender",
	"\u1019\u103c\u1014\u103a\u1019\u102c \u1015\u103c\u1000\u1039\u1001\u1012\u102d\u1014\u103a": "Myanmar-Kalender",
	"\u5f5d\u66c6": "Yi-Kalender",
	"\u0939\u093f\u0928\u094d\u0926\u0942 \u092a\u0902\u091a\u093e\u0902\u0917": "Hindu-Kalender",
	"\u06af\u0627\u0647\u200c\u0634\u0645\u0627\u0631\u06cc \u0628\u0647\u0627\u0626\u06cc": "Bah\u00e1\u2019\u00ed-Kalender",
	"\u79d1\u666e\u7279\u66c6": "Koptischer Kalender",
	"\u8863\u7d22\u6bd4\u4e9e\u66c6": "\u00c4thiopischer Kalender",
	"\u6559\u6703\u4e9e\u7f8e\u5c3c\u4e9e\u66c6": "Armenischer Kalender",
	"Byzantine calendar": "Byzantinischer Kalender",
	"\u53e4\u57c3\u53ca\u66c6": "\u00c4gyptischer Kalender",
	"\u6771\u4e9e\u9670\u967d\u66c6": "Ostasiatischer Kalender",
	"\u4e2d\u570b": "China",
	"\u6708\u306e\u5225\u540d": "Japanischer Monatsname",
	"\u66dc\u65e5": "Wochentag (japanisch)",
	"\u4e8c\u5341\u516b\u5bbf": "28 H\u00e4user",
	"zodiac sign": "Sternzeichen",
	"\u751f\u8096": "Chinesisches Tierkreiszeichen",
	"Year numbering": "Jahreszahl",
	"\u8457\u540d\u5730\u9ede\uff1a": "Ber\u00fchmte Orte:",
	"Loading %1%...": "Laden %1%...",
	"finished": "fertig",
	"No changes.": "Keine \u00c4nderungen.",
	"\u4e0a\u5f26": "erstes Viertel",
	"\u671b": "Vollmond",
	"\u4e0b\u5f26": "letztes Viertel",
	"partial lunar eclipse": "partielle Mondfinsternis",
	"partial solar eclipse": "partielle Sonnenfinsternis",
	"total lunar eclipse": "totale Mondfinsternis",
	"total solar eclipse": "totale Sonnenfinsternis",
	"lunar eclipse": "Mondfinsternis",
	"solar eclipse": "Sonnenfinsternis",
	"moonrise": "Mondaufgang",
	"sunrise": "Sonnenaufgang",
	"moonset": "Monduntergang",
	"sunset": "Sonnenuntergang",
	"astronomical twilight begin": "Beginn der astronomischen D\u00e4mmerung",
	"civil twilight begin": "Beginn der b\u00fcrgerlichen D\u00e4mmerung",
	"nautical twilight begin": "Beginn der nautischen D\u00e4mmerung",
	"astronomical twilight end": "Ende der astronomischen D\u00e4mmerung",
	"civil twilight end": "Ende der b\u00fcrgerlichen D\u00e4mmerung",
	"nautical twilight end": "Ende der nautischen D\u00e4mmerung",
	"log-type-error": "Fehler",
	"Not Yet Implemented!": "Noch nicht implementiert!",
	"Language": "Sprache",
	"Comma-separator": ", ",
	"Abandon change": "\u00c4nderung verwerfen",
	"No reason provided": "Es wurde kein Grund angegeben",
	"No content": "Kein Inhalt",
	"%1 {{PLURAL:%1|result|results}}": "%1 {{PLURAL:%1|Ergebnis|Ergebnisse}}",
	"Invalid title: %1": "Ung\u00fcltiger Titel: %1",
	"Invalid parameter: %1": "Ung\u00fcltiger Parameter: %1",
	"Too many failed login attempts: %1": "Zu viele fehlgeschlagene Login-Versuche: %1",
	"\u7121\u9801\u9762\u91cd\u5b9a\u5411\u81f3\u672c\u9801": "Keine andere Seite leitet auf diese Seite weiter",
	"no change": "keine \u00c4nderung",
	"Missing page": "Fehlende Seite",
	"Invalid page title": "Ung\u00fcltiger Seitenname",
	"file": "Datei",
	"files": "Dateien",
	"function": "Funktion",
	"number": "Zahl",
	"MESSAGE_NEED_RE_DOWNLOAD": "Der Download ist fehlgeschlagen, m\u00f6glicherweise ist der Server vor\u00fcbergehend nicht verf\u00fcgbar oder die Datei ist verloren gegangen (404). Bitte best\u00e4tige, dass der Fehler behoben wurde oder der Fehler nicht mehr besteht, und f\u00fchre den Download erneut aus.",
	"Retry %1/%2": "%1/%2 erneut versuchen",
	"Contents": "Inhalt",
	"Italy": "Italien",
	"Poland": "Polen",
	"Portugal": "Portugal",
	"Luxembourg": "Luxemburg",
	"Netherlands": "Niederlande",
	"Bavaria": "Bayern",
	"Austria": "\u00d6sterreich",
	"Switzerland": "Schweiz",
	"Hungary": "Ungarn",
	"Germany": "Deutschland",
	"Norway": "Norwegen",
	"Denmark": "D\u00e4nemark",
	"Sweden": "Schweden",
	"Finland": "Finnland",
	"Bulgaria": "Bulgarien",
	"Soviet Union": "Sowjetunion",
	"Serbia": "Serbien",
	"Romania": "Rum\u00e4nien",
	"Greece": "Griechenland",
	"T\u00fcrkiye": "T\u00fcrkei",
	"Egypt": "\u00c4gypten",
	"%1 {{PLURAL:%1|minute|minutes}}": "%1 {{PLURAL:%1|Minute|Minuten}}",
	"now": "jetzt",
	"several seconds ago": "vor einigen Sekunden",
	"soon": "bald",
	"%1 {{PLURAL:%1|second|seconds}} ago": "vor %1 Sekunden",
	"%1 {{PLURAL:%1|second|seconds}} later": "%1 Sekunden sp\u00e4ter",
	"%1 {{PLURAL:%1|minute|minutes}} ago": "vor %1 Minuten",
	"%1 {{PLURAL:%1|minute|minutes}} later": "%1 Minuten sp\u00e4ter",
	"%1 {{PLURAL:%1|hour|hours}} ago": "vor %1 Stunden",
	"%1 {{PLURAL:%1|hour|hours}} later": "%1 Stunden sp\u00e4ter",
	"%1 {{PLURAL:%1|day|days}} ago": "vor %1 Tagen",
	"%1 {{PLURAL:%1|day|days}} later": "%1 Tage sp\u00e4ter",
	"\u7409\u7403": "Ryukyu",
	"\u65e5\u672c": "Japan",
	"\ud55c\uad6d": "Korea",
	"\u0e44\u0e17\u0e22": "Thailand",
	"India": "Indien",
	"\u2191Back to TOC": "\u2191Zur\u00fcck zum Inhaltsverzeichnis",
	"Contents of [%1]": "Inhalt von [%1]",
	"expand": "ausklappen",
	"collapse": "einklappen",
	"user": "Benutzer",
	"\u8a9e\u8a00\u6578": "Anzahl der Sprachen",
	"\u4f5c\u54c1\u5df2\u5b8c\u7d50\u3002": "Serie ist beendet."
},
"de-DE");

==> cejs-4.5.6.tgz: package/application/locale/resources/de-DE.js <==
/*	Localized messages of CeL.
	This file is auto created by auto-generate tool: build.nodejs(.js) @ 2023.
*/'use strict';typeof CeL==='function'&&CeL.application.locale.gettext.set_text({
	"Espa\u00f1a": "Spanien",
	"Calendrier r\u00e9publicain": "Franz\u00f6sischer republikanischer Kalender",
	"untranslated message count": "1000+",
	"\u6e05\u9664\u8a0a\u606f": "Protokoll l\u00f6schen",
	"\u986f\u793a/\u96b1\u85cf\u8a0a\u606f": "Protokoll anzeigen / ausblenden",
	"Load failed": "Laden fehlgeschlagen",
	"\u8a0a\u606f\u63d0\u793a\u8207\u7d00\u9304\u6b04": "Log-Konsole",
	"\u5730\u7406\u5ea7\u6a19\uff1a": "Koordinaten: ",
	"\u81ea\u8a02\u8f38\u51fa\u683c\u5f0f": "Ausgabeformat anpassen",
	"\u7def\u5ea6\uff1a": "Breitengrad: ",
	"\u7d93\u5ea6\uff1a": "L\u00e4ngengrad: ",
	"\u8f38\u51fa\u683c\u5f0f": "Ausgabeformat",
	"\u524d\u7db4": "Pr\u00e4fix",
	"\u6642\u5340\uff1a": "Zeitzone: ",
	"\u671d\u4ee3\u7d00\u5e74\u65e5\u671f": "Datum der Kalenderepoche",
	"\u516c\u5143\u65e5\u671f": "Datum einer gew\u00f6hnlichen \u00c4ra",
	"Loading...": "Laden...",
	"\u1019\u103c\u1014\u103a\u1019\u102c": "Myanmar",
	"Vi\u1ec7t Nam": "Vietnam",
	"\u9664\u53bb\u6b64\u6b04": "Spalte entfernen",
	"\u5206\u985e": "Gruppe",
	"%1/%2/%3": "%1/%2/%3",
	"\u5e74\u8b5c": "Kalenderdatum",
	"\u5168\u4e0d\u9078": "ALLE entfernen",
	"\u589e\u52a0\u6b64\u6b04": "Spalte hinzuf\u00fcgen",
	"\u81fa\u7063\u5730\u9707": "Erdbeben in Taiwan",
	"\u5c0e\u89bd\u5217\uff1a": "Navigation:",
	"\u6240\u6709\u570b\u5bb6": "Alle L\u00e4nder",
	"France": "Frankreich",
	"Great Britain": "Gro\u00dfbritannien",
	"Spain": "Spanien",
	"\u541b\u4e3b\u865f": "K\u00fcnstlername",
	"\u51fa\u751f": "Geboren",
	"\u901d\u4e16": "Gestorben",
	"\u5728\u4f4d": "Regierungszeit",
	"\u52a0\u5195": "Kr\u00f6nung",
	"\u524d\u4efb": "Vorg\u00e4nger",
	"\u7e7c\u4efb": "Nachfolger",
	"\u7236\u89aa": "Vater",
	"\u6bcd\u89aa": "Mutter",
	"Initializing...": "Initialisiere\u2026",
	"Aries": "Widder",
	"Taurus": "Stier",
	"Gemini": "Zwilling",
	"Cancer": "Krebs",
	"Leo": "L\u00f6we",
	"Virgo": "Jungfrau",
	"Libra": "Waage",
	"Scorpio": "Skorpion",
	"Sagittarius": "Sch\u00fctze",
	"Capricorn": "Steinbock",
	"Aquarius": "Wassermann",
	"Pisces": "Fische",
	"\u6708\u76f8": "Mondphase",
	"\u661f\u671f": "Wochentag",
	"\u6714": "Neumond",
	"\u65e5\u51fa\u65e5\u843d": "Sonnenaufgang / Sonnenuntergang",
	"\u66d9\u66ae\u5149": "D\u00e4mmerung",
	"\u6708\u51fa\u6708\u843d": "Mondaufgang / Monduntergang",
	"calendar": "Kalender",
	"Gregorian calendar": "Gregorianischer Kalender",
	"Julian calendar": "Julianischer Kalender",
	"\u4f0a\u65af\u862d\u66c6": "Islamischer Kalender",
	"\u06af\u0627\u0647\u200c\u0634\u0645\u0627\u0631\u06cc \u0647\u062c\u0631\u06cc \u062e\u0648\u0631\u0634\u06cc\u062f\u06cc": "Moderner iranischer Kalender",
	"\u5e0c\u4f2f\u4f86\u66c6": "Hebr\u00e4ischer Kalender",
	"\u9577\u7d00\u66c6": "Lange Z\u00e4hlung",
	"\u50a3\u66c6": "Dai-Kalender",
	"\u1019\u103c\u1014\u103a\u1019\u102c \u1015\u103c\u1000\u1039\u1001\u1012\u102d\u1014\u103a": "Myanmar-Kalender",
	"\u5f5d\u66c6": "Yi-Kalender",
	"\u0939\u093f\u0928\u094d\u0926\u0942 \u092a\u0902\u091a\u093e\u0902\u0917": "Hindu-Kalender",
	"\u06af\u0627\u0647\u200c\u0634\u0645\u0627\u0631\u06cc \u0628\u0647\u0627\u0626\u06cc": "Bah\u00e1\u2019\u00ed-Kalender",
	"\u79d1\u666e\u7279\u66c6": "Koptischer Kalender",
	"\u8863\u7d22\u6bd4\u4e9e\u66c6": "\u00c4thiopischer Kalender",
	"\u6559\u6703\u4e9e\u7f8e\u5c3c\u4e9e\u66c6": "Armenischer Kalender",
	"Byzantine calendar": "Byzantinischer Kalender",
	"\u53e4\u57c3\u53ca\u66c6": "\u00c4gyptischer Kalender",
	"\u6771\u4e9e\u9670\u967d\u66c6": "Ostasiatischer Kalender",
	"\u4e2d\u570b": "China",
	"\u6708\u306e\u5225\u540d": "Japanischer Monatsname",
	"\u66dc\u65e5": "Wochentag (japanisch)",
	"\u4e8c\u5341\u516b\u5bbf": "28 H\u00e4user",
	"zodiac sign": "Sternzeichen",
	"\u751f\u8096": "Chinesisches Tierkreiszeichen",
	"Year numbering": "Jahreszahl",
	"\u8457\u540d\u5730\u9ede\uff1a": "Ber\u00fchmte Orte:",
	"Loading %1%...": "Laden %1%...",
	"The bot operation is completed %1% in total": "Die Bot-Operation ist zu %1% abgeschlossen",
	"finished": "fertig",
	"No changes.": "Keine \u00c4nderungen.",
	"No page modified": "Keine Seite bearbeitet",
	"astronomy": "Astronomie",
	"\u4e0a\u5f26": "erstes Viertel",
	"\u671b": "Vollmond",
	"\u4e0b\u5f26": "letztes Viertel",
	"partial lunar eclipse": "partielle Mondfinsternis",
	"partial solar eclipse": "partielle Sonnenfinsternis",
	"total lunar eclipse": "totale Mondfinsternis",
	"total solar eclipse": "totale Sonnenfinsternis",
	"lunar eclipse": "Mondfinsternis",
	"solar eclipse": "Sonnenfinsternis",
	"moonrise": "Mondaufgang",
	"sunrise": "Sonnenaufgang",
	"moonset": "Monduntergang",
	"sunset": "Sonnenuntergang",
	"astronomical twilight begin": "Beginn der astronomischen D\u00e4mmerung",
	"civil twilight begin": "Beginn der b\u00fcrgerlichen D\u00e4mmerung",
	"nautical twilight begin": "Beginn der nautischen D\u00e4mmerung",
	"astronomical twilight end": "Ende der astronomischen D\u00e4mmerung",
	"civil twilight end": "Ende der b\u00fcrgerlichen D\u00e4mmerung",
	"nautical twilight end": "Ende der nautischen D\u00e4mmerung",
	"log-type-error": "Fehler",
	"Not Yet Implemented!": "Noch nicht implementiert!",
	"Language": "Sprache",
	"Comma-separator": ", ",
	"Abandon change": "\u00c4nderung verwerfen",
	"No reason provided": "Es wurde kein Grund angegeben",
	"No content": "Kein Inhalt",
	"%1 {{PLURAL:%1|result|results}}": "%1 {{PLURAL:%1|Ergebnis|Ergebnisse}}",
	"Invalid title: %1": "Ung\u00fcltiger Titel: %1",
	"Invalid parameter: %1": "Ung\u00fcltiger Parameter: %1",
	"Too many failed login attempts: %1": "Zu viele fehlgeschlagene Login-Versuche: %1",
	"\u7121\u9801\u9762\u91cd\u5b9a\u5411\u81f3\u672c\u9801": "Keine andere Seite leitet auf diese Seite weiter",
	"no change": "keine \u00c4nderung",
	"Missing page": "Fehlende Seite",
	"Invalid page title": "Ung\u00fcltiger Seitenname",
	"No user name or password provided. The login attempt was abandoned.": "Kein Benutzername oder Passwort angegeben. Der Anmeldeversuch wurde abgebrochen.",
	"file": "Datei",
	"files": "Dateien",
	"fso_file": "Dateipfad",
	"fso_files": "Dateipfade",
	"function": "Funktion",
	"number": "Zahl",
	"MESSAGE_NEED_RE_DOWNLOAD": "Der Download ist fehlgeschlagen, m\u00f6glicherweise ist der Server vor\u00fcbergehend nicht verf\u00fcgbar oder die Datei ist verloren gegangen (404). Bitte best\u00e4tige, dass der Fehler behoben wurde oder der Fehler nicht mehr besteht, und f\u00fchre den Download erneut aus.",
	"Retry %1/%2": "%1/%2 erneut versuchen",
	"File size: %1.": "Dateigr\u00f6\u00dfe: %1.",
	"Contents": "Inhalt",
	"Italy": "Italien",
	"Poland": "Polen",
	"Portugal": "Portugal",
	"Luxembourg": "Luxemburg",
	"Netherlands": "Niederlande",
	"Bavaria": "Bayern",
	"Austria": "\u00d6sterreich",
	"Switzerland": "Schweiz",
	"Hungary": "Ungarn",
	"Germany": "Deutschland",
	"Norway": "Norwegen",
	"Denmark": "D\u00e4nemark",
	"Sweden": "Schweden",
	"Finland": "Finnland",
	"Bulgaria": "Bulgarien",
	"Soviet Union": "Sowjetunion",
	"Serbia": "Serbien",
	"Romania": "Rum\u00e4nien",
	"Greece": "Griechenland",
	"T\u00fcrkiye": "T\u00fcrkei",
	"Egypt": "\u00c4gypten",
	"%1 {{PLURAL:%1|minute|minutes}}": "%1 {{PLURAL:%1|Minute|Minuten}}",
	"now": "jetzt",
	"several seconds ago": "vor einigen Sekunden",
	"soon": "bald",
	"%1 {{PLURAL:%1|second|seconds}} ago": "vor %1 {{PLURAL:%1|Sekunde|Sekunden}}",
	"%1 {{PLURAL:%1|second|seconds}} later": "%1 {{PLURAL:$1|Sekunde|Sekunden}} sp\u00e4ter",
	"%1 {{PLURAL:%1|minute|minutes}} ago": "vor %1 Minuten",
	"%1 {{PLURAL:%1|minute|minutes}} later": "%1 Minuten sp\u00e4ter",
	"%1 {{PLURAL:%1|hour|hours}} ago": "vor %1 Stunden",
	"%1 {{PLURAL:%1|hour|hours}} later": "%1 Stunden sp\u00e4ter",
	"%1 {{PLURAL:%1|day|days}} ago": "vor %1 Tagen",
	"%1 {{PLURAL:%1|day|days}} later": "%1 Tage sp\u00e4ter",
	"\u7409\u7403": "Ryukyu",
	"\u65e5\u672c": "Japan",
	"\ud55c\uad6d": "Korea",
	"\u0e44\u0e17\u0e22": "Thailand",
	"India": "Indien",
	"\u2191Back to TOC": "\u2191Zur\u00fcck zum Inhaltsverzeichnis",
	"Contents of [%1]": "Inhalt von [%1]",
	"expand": "ausklappen",
	"collapse": "einklappen",
	"Duplicate task name %1! Will overwrite old task with new task: %2\u2192%3": "Doppelter Aufgabenname %1! \u00dcberschreibt die alte Aufgabe mit der neuen Aufgabe: %2\u2192%3",
	"\u8de8\u8a9e\u8a00\u6a21\u677f\u7684\u672c\u5730\u6a19\u984c\u8207\u5916\u8a9e\u6a19\u984c\u76f8\u540c": "Der lokale Titel in der interlingualen Vorlage ist derselbe wie der fremdsprachige Titel",
	"Local page title contains the local title in the interlanguage template": "Lokaler Seitentitel enth\u00e4lt den lokalen Titel in der Interlanguage-Vorlage",
	"user": "Benutzer",
	"%1 {{PLURAL:%1|page|pages}} modified": "%1 {{PLURAL:%1|Seite|Seiten}} bearbeitet",
	"Fixing broken anchor": "Korrigiere defekten Abschnittslink",
	"Remove %1 non-defunct {{PLURAL:%1|anchor|anchors}}": "Entferne %1 {{PLURAL:%1|defekten|defekte}} Abschnittstitel",
	"Anchor %1 links to a specific web page: %2.": "Abschnittstitel %1 verlinkt auf Webseite %2.",
	"The anchor (%2) [[Special:Diff/%1|has been deleted]].": "Der Abschnittstitel %2 wurde schon einmal [[Spezial:Diff/%1|von einem anderen Benutzer]] gel\u00f6scht.",
	"Reminder of an inactive anchor": "Erinnerung an einen inaktiven Abschnittstitel",
	"Update links to archived section %1: %2": "Aktualisiere Links auf archivierten Abschnitt %1: %2",
	"Incorrect capitalization/spaced section title": "Falsche Gro\u00df- und Kleinschreibung oder Zusammen- und Getrenntschreibung in der Abschnitts\u00fcberschrift",
	"\u7e41\u7c21\u4e0d\u7b26\u5339\u914d\u800c\u5931\u6548\u7684\u7db2\u9801\u9328\u9ede": "Inkonsistenz zwischen traditionellem und vereinfachtem Chinesisch",
	"VERY DIFFERENT": "SEHR UNTERSCHIEDLICH",
	"Please help to check this edit.": "Bitte hilf dabei, diese Bearbeitung zu pr\u00fcfen.",
	"%1\u2192most alike anchor %2": "%1 am \u00e4hnlichsten zu Abschnitt %2",
	"\u8a9e\u8a00\u6578": "Anzahl der Sprachen",
	"\u4f5c\u54c1\u5df2\u5b8c\u7d50\u3002": "Serie ist beendet."
},
"de-DE");
